==> zio-aws-mediatailor_3-5.17.103.1-sources.jar: zio/aws/mediatailor/model/ConfigureLogsForPlaybackConfigurationRequest.scala <==
package zio.aws.mediatailor.model
import java.lang.Integer
import zio.aws.mediatailor.model.primitives.{__string, __integer}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class ConfigureLogsForPlaybackConfigurationRequest(
    percentEnabled: __integer,
    playbackConfigurationName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest = {
    import ConfigureLogsForPlaybackConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest
      .builder()
      .percentEnabled(__integer.unwrap(percentEnabled): Integer)
      .playbackConfigurationName(
        __string.unwrap(playbackConfigurationName): java.lang.String
      )
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest.ReadOnly =
    zio.aws.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest
      .wrap(buildAwsValue())
}
object ConfigureLogsForPlaybackConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest =
      zio.aws.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest(
        percentEnabled,
        playbackConfigurationName
      )
    def percentEnabled: __integer
    def playbackConfigurationName: __string
    def getPercentEnabled: ZIO[Any, Nothing, __integer] =
      ZIO.succeed(percentEnabled)
    def getPlaybackConfigurationName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(playbackConfigurationName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest
  ) extends zio.aws.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest.ReadOnly {
    override val percentEnabled: __integer =
      zio.aws.mediatailor.model.primitives.__integer(impl.percentEnabled())
    override val playbackConfigurationName: __string =
      zio.aws.mediatailor.model.primitives
        .__string(impl.playbackConfigurationName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest
  ): zio.aws.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.19.33.1-sources.jar: zio/aws/mediatailor/model/ConfigureLogsForPlaybackConfigurationRequest.scala <==
package zio.aws.mediatailor.model
import java.lang.Integer
import zio.aws.mediatailor.model.primitives.{__string, __integer}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class ConfigureLogsForPlaybackConfigurationRequest(
    percentEnabled: __integer,
    playbackConfigurationName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest = {
    import ConfigureLogsForPlaybackConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest
      .builder()
      .percentEnabled(percentEnabled: Integer)
      .playbackConfigurationName(playbackConfigurationName: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest.ReadOnly =
    zio.aws.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest
      .wrap(buildAwsValue())
}
object ConfigureLogsForPlaybackConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest =
      zio.aws.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest(
        percentEnabled,
        playbackConfigurationName
      )
    def percentEnabled: __integer
    def playbackConfigurationName: __string
    def getPercentEnabled: ZIO[Any, Nothing, __integer] =
      ZIO.succeed(percentEnabled)
    def getPlaybackConfigurationName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(playbackConfigurationName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest
  ) extends zio.aws.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest.ReadOnly {
    override val percentEnabled: __integer = impl.percentEnabled(): __integer
    override val playbackConfigurationName: __string =
      impl.playbackConfigurationName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest
  ): zio.aws.mediatailor.model.ConfigureLogsForPlaybackConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}
